@@ -9,6 +9,9 @@ class Character(models.Model):
     book = models.ManyToManyField(Book, blank=True,null=True)
     bioshort = models.CharField(max_length=500,blank=True,null=True)
     biolong = models.TextField(blank=True,null=True)
+    def __unicode__(self):
+        return self.name
+
     class Meta:
         db_table='plicata_characters_characters'
 
@@ -18,6 +21,9 @@ class CharacterGroup(models.Model):
     groupname = models.TextField(max_length=80)
     grouptype = models.TextField(max_length=80)
     members = models.ManyToManyField(Character)
+    def __unicode__(self):
+        return self.groupname
+
     class Meta:
         db_table = 'plicata_characters_charactergroups'
 
@@ -36,6 +42,8 @@ class Nickname(models.Model):
     physical = models.NullBooleanField(default=None) # eg Fatso, Red, Baldy
     personality = models.NullBooleanField(default=None) # eg Grumpy, Crazy, Drunken, Brainy, Dopey
     surname = models.NullBooleanField(default=None) # use of persons last name
+    def __unicode__(self):
+        return self.nickname
 
     class Meta:
         db_table='plicata_characters_nicknames'
